@@ -54,10 +54,51 @@ def get_all_text_files_in_folder(start_folder, excluded_folders=exclude_folders,
         dirs[:] = [d for d in dirs if d not in exclude_folders]
         files[:] = [f for f in files if f not in exclude_files]
         for fn in files:
-            if re.findall(r"-\w\w\w\d(?:.inProgress|completed|mARkdown)?\Z", fn):
+            if re.findall(r"-\w\w\w\d(?:.inProgress|.completed|.mARkdown)?\Z", fn):
                 fp = os.path.join(root, fn)
                 yield(fp)
 
+#def get_all_yml_files_in_folder(start_folder, yml_type,
+def get_all_yml_files_in_folder(start_folder, yml_types,
+                                excluded_folders=exclude_folders,
+                                exclude_files=exclude_files):
+    """A generator that yields the file path for all yml files \
+    of a specific type in a folder and its subfolders.
+
+    OpenITI yml files exist for authors, books and versions.
+    
+    The script creates a generator over which you can iterate.
+    It yields the full path to each of the yml files.
+
+    Args:
+        start_folder (str): path to the folder containing the text files
+        yml_type (list): list of desired yml file types:
+            one or more of "author", "book", or "version"
+        excluded_folders (list): list of folder names that should be excluded
+            (default: the list of excluded folders defined in this module)
+        excluded_files (list): list of file names that should be excluded
+            (default: the list of excluded file names defined in this module)
+
+    Examples:
+        > folder = r"D:\London\OpenITI\25Y_repos"
+        > for fp in get_all_yml_files_in_folder(folder):
+            print(fp)
+        > folder = r"D:\London\OpenITI\25Y_repos\0025AH"
+        > AH0025_file_list = [fp for fp in get_all_text_files_in_folder(folder)]
+    """
+    dots = {"author": 1, "book": 2, "version": 3}
+    if isinstance(yml_types, str):
+        yml_types = [yml_types,]
+    for root, dirs, files in os.walk(start_folder):
+        dirs[:] = [d for d in dirs if d not in exclude_folders]
+        files[:] = [f for f in files if f not in exclude_files]
+        for fn in files:
+            for yml_type in yml_types:
+                if re.findall(r"^(?:[^.]+\.){%s}yml$" % dots[yml_type], fn):
+                    fp = os.path.join(root, fn)
+                    yield(fp)
+
+
 def get_all_characters_in_text(fp):
     """Get a set of all characters used in a text.
 
@@ -147,7 +188,7 @@ def text_cleaner(text):
     Returns:
         (str): the cleaned string
     """
-    text = ara.normalize_ara_extra_light(text)
+    text = ara.normalize_ara_light(text)
     text = re.sub("\W|\d|[A-z]", " ", text)
     text = re.sub(" +", " ", text)
     return text
@@ -187,11 +228,12 @@ def generate_ids_through_permutations(char_string_for_ids, id_len_char, limit):
 
 
 
-def read_header(fp):
+def read_header(fp, lines=300):
     """Read only the OpenITI header of a file without opening the entire file.
 
     Args:
         fp (str): path to the text file
+        lines (int): number of lines at the top of the file to be read
 
     Returns:
         (list): A list of all metadata lines in the header
@@ -200,7 +242,7 @@ def read_header(fp):
         header = []
         line = file.readline()
         i=0
-        while i < 100:
+        while i < lines:
         #while "#META#Header#End" not in line and i < 100:
             #if "#META#" in line or "#NewRec#" in line:
             header.append(line)
@@ -208,6 +250,7 @@ def read_header(fp):
                 return header
             line = file.readline() # move to next line
             i += 1
+        print("{}: header splitter not reached after {} lines".format(fp, lines))
     return header
 
 
